# Generated by roxygen2: do not edit by hand

S3method(plot,compare_indices)
S3method(print,batch_analysis)
S3method(print,compare_indices)
S3method(print,ozkan_pto)
S3method(print,ozkan_pto_resample)
S3method(print,ozkan_pto_sensitivity)
S3method(print,rarefaction_taxonomic)
S3method(print,td_simulation)
S3method(summary,batch_analysis)
S3method(summary,compare_indices)
S3method(summary,ozkan_pto_resample)
S3method(summary,ozkan_pto_sensitivity)
S3method(summary,rarefaction_taxonomic)
export(avtd)
export(batch_analysis)
export(build_tax_tree)
export(compare_indices)
export(delta)
export(delta_star)
export(deng_entropy_level)
export(ozkan_pto)
export(ozkan_pto_full)
export(ozkan_pto_jackknife)
export(ozkan_pto_resample)
export(ozkan_pto_sensitivity)
export(plot_bubble)
export(plot_funnel)
export(plot_heatmap)
export(plot_iteration)
export(plot_radar)
export(plot_rarefaction)
export(plot_taxonomic_tree)
export(pto_components)
export(rarefaction_taxonomic)
export(shannon)
export(simpson)
export(simulate_td)
export(tax_distance_matrix)
export(vartd)
importFrom(rlang,.data)
importFrom(stats,setNames)
